.. python-eduvpn-client documentation master file, created by
   sphinx-quickstart on Wed Aug  2 15:37:37 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to python-eduvpn-client's documentation!
================================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   introduction
   API
   developer


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
